import requests
from bs4 import BeautifulSoup
import pandas as pd
from urllib.parse import urljoin, urlparse
import re  

# Nastavení hlaviček User-Agent
headers = {
    'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/58.0.3029.110 Safari/537.3'
}

def get_image_size(url):
    # Přeskočit URL, které nejsou http nebo https (např. data: uri)
    if not url.startswith(('http://', 'https://')):
        print(f"Přeskočení neplatné URL pro obrázek: {url}")
        return 0  # Vrátí 0 jako velikost obrázku, pokud URL není platné http/https
    try:
        response = requests.head(url, allow_redirects=True, headers=headers)
        size_in_bytes = int(response.headers.get('Content-Length', 0))
        size_in_kb = size_in_bytes / 1024
        return size_in_kb
    except Exception as e:
        print(f"Chyba při získávání velikosti obrázku {url}: {e}")
        return 0

def get_image_format(url):
    format_match = re.search(r'\.(jpg|jpeg|png|gif|bmp|svg|webp)$', url, re.IGNORECASE)
    if format_match:
        return format_match.group(1)
    else:
        return "Neznámý" if url.startswith(('http://', 'https://')) else "Není obrázek"

def is_from_cdn(url):
    parsed_url = urlparse(url)
    cdn_domains = [
        'cdn.', 'cloudfront.', 'akamai.', 'fastly.', 'kxcdn.', 'cdn77.', 'cdnify.', 'stackpath.',
        'wixstatic.com'  # Přidání běžných CDN
    ]
    return any(cdn in parsed_url.netloc for cdn in cdn_domains)

def is_lazy_loaded(img_tag):
    return "Ano" if 'loading' in img_tag.attrs and img_tag['loading'] == 'lazy' else "Ne"

def get_alt_text(img_tag):
    return img_tag.get('alt', 'Bez alt textu')  # Vrátí alt text nebo výchozí hodnotu, pokud není k dispozici

base_url = 'https://example.com'  # Nahraďte 'https://example.com' skutečným URL
base_domain = urlparse(base_url).netloc  # Získání domény z base_url

response = requests.get(base_url, headers=headers)
soup = BeautifulSoup(response.text, 'html.parser')

data = []

visited_urls = set()  # Množina pro uchování již navštívených URL adres

links_to_visit = set([base_url])  

while links_to_visit:
    page_url = links_to_visit.pop()
    if page_url not in visited_urls:
        try:
            visited_urls.add(page_url)

            print(f"Procházení stránky: {page_url}")
            
            page_response = requests.get(page_url, headers=headers)
            page_soup = BeautifulSoup(page_response.text, 'html.parser')
            img_tags = page_soup.find_all('img', src=True)
            for img in img_tags:
                img_url = urljoin(page_url, img['src'])
                
                if not img_url.startswith(('http://', 'https://')):  # Přeskočení neplatných URL
                    continue
                
                img_size_kb = get_image_size(img_url)
                image_format = get_image_format(img_url)
                alt_text = get_alt_text(img)
                size_status = "Příliš velké" if img_size_kb > 100 else "OK"
                from_cdn = "Ano" if is_from_cdn(img_url) else "Ne"
                lazy_loaded = is_lazy_loaded(img)
                
                data.append({
                    'URL Stránky': page_url,
                    'URL Obrázku': img_url,
                    'Alt Text': alt_text,
                    'Velikost Obrázku (KB)': img_size_kb,
                    'Formát Obrázku': image_format,
                    'Velikost Stav': size_status,
                    'Z CDN': from_cdn,
                    'Lazy Loaded': lazy_loaded
                })
                
            links_to_visit.update(set([urljoin(page_url, link['href']) for link in page_soup.find_all('a', href=True) if urlparse(urljoin(page_url, link['href'])).netloc == base_domain and urljoin(page_url, link['href']) not in visited_urls]))
        except Exception as e:
            print(f"Chyba při procházení {page_url}: {e}")

df = pd.DataFrame(data)
if not df.empty:
    df.to_csv('vyscrapovane_obrazky_detaily.csv', index=False)
    print("Scrapování dokončeno. Data uložena do 'vyscrapovane_obrazky_detaily.csv'.")
else:
    print("Nebyla nalezena žádná data pro uložení.")
